@@ -1,30 +1,43 @@
 import random
 import requests
-import string,re
-import base64,json
+import string
+import re
+import os
+import base64
+import json
+import time
+import logging
 from bs4 import BeautifulSoup
-from requests_html import HTMLSession
+from cloudscraper import CloudScraper
+from urllib.parse import quote as urlquote ,unquote
+from urllib.request import urlopen
 import urllib
-from .func import (MORSE_CODE_DICT,payloads_response,gpt_4_mode,payload8)
+from requests_html import HTMLSession
+from MukeshAPI.func import (MORSE_CODE_DICT)
 from base64 import b64decode as m,b64encode as n
-from .words import wordshub
+from MukeshAPI.words import wordshub
 from PIL import Image, ImageDraw, ImageFont
+from MukeshAPI.truth_dare import TRUTH,DARE
 
-__version__ = "0.6.5.3"
+logging.basicConfig(level=logging.INFO)
+logger = logging.getLogger(__name__)
 
-__all__ = ["api","Data"]
+__version__ = "0.7.3"
 
+__all__ = ["api"]
 
 class MukeshAPI:
-    
-    def __init__(self)->None:
+    def __init__(self) -> None:
         """Api for various purpose
     support group : https://t.me/the_support_chat
     owner : @mr_sukkun
+    Docs :
         """
+        logger.info("Welcome to MukeshAPI! This is a Python package that provides various APIs for developers.")
         pass
     
-    def datagpt(self,args:str):
+    @staticmethod
+    def datagpt(args:str):
         """
         Sends a query to a specified datagpt API endpoint to retrieve a response based on the provided question.
 
@@ -35,11 +48,13 @@ class MukeshAPI:
             str: The response text from the datagpt API.
 
         Example usage:
-        >>> from MukeshAPI import api
-        >>> response = api.datagpt("What are the latest trends in AI?")
-        >>> print(response)
+        
+            >>> from MukeshAPI import api
+            >>> response = api.datagpt("What are the latest trends in AI?")
+            >>> print(response)
         """
-        url = m("aHR0cHM6Ly9hcHAuY3JlYXRvci5pby9hcGkvY2hhdA==").decode("utf-8")
+
+        url=m("aHR0cHM6Ly9hcHAuY3JlYXRvci5pby9hcGkvY2hhdA==").decode("utf-8")
         payload = {
             "question": args,
             "chatbotId": "712544d1-0c95-459e-ba22-45bae8905bed",
@@ -50,18 +65,17 @@ class MukeshAPI:
         try:
             response = requests.post(url, json=payload)
             extracted_text = re.findall(r"\{(.*?)\}", response.text, re.DOTALL)
-            extracted_json = "{" + extracted_text[0] + "}]}"
-            json_text = extracted_json.replace('\n', ' ')
+            extracted_json = "{" + extracted_text[0] + "}]}".replace('\n', ' ')
 
-            data = json.loads(json_text)
-            return {"results":data["text"],"join": "@Mr_Sukkun", "success": True
-                    }
+            data = json.loads(extracted_json)
+            return {"results":data["text"],"join": "@Mr_Sukkun", "success": True}
         except Exception as e:
             return e   
     
-    def blackpink(self,args):
+    @staticmethod
+    def blackpink(args):
         """generate blackpink  image from text
-    """
+        """
         text = args
         font_path = os.path.dirname(__file__)+"blackpink.otf"
         font_size = 230
@@ -85,97 +99,32 @@ class MukeshAPI:
         img_str = n(buffered.getvalue()).decode("utf-8")
         return img_str
     
-    def blackbox(self,args: str) -> requests.Response:
+
+    @staticmethod
+    def chatgpt(args: str):
         """
-        Interact with the Blackbox AI API for generating content. 🧠
+        Sends a query to a specified ChatGPT API endpoint to retrieve a response based on the provided question.
 
         Args:
-            args (str): The input text to interact with the Blackbox AI chat API.
-
+            args (str): The question or input for ChatGPT.
         Returns:
-            requests.Response: The response object from the API request.
+            str: The response text from the ChatGPT API.
 
         Example usage:
-        >>> from MukeshAPI import api
-        >>> response = api.blackbox("Hello, how are you?")
-        >>> print(response.text)
-        {
-            "response": "Generated content response",
-            "status": 200
-        }
+            >>> from MukeshAPI import api
+            >>> response = api.chatgpt("hi there")
+            >>> print(response)
         """
-
-        url = m('aHR0cHM6Ly93d3cuYmxhY2tib3guYWkvYXBpL2NoYXQ=').decode("utf-8")
+        session = requests.Session()
+        url = m("aHR0cHM6Ly9jaGF0d2l0aGFpLmNvZGVzZWFyY2gud29ya2Vycy5kZXYvP2NoYXQ9").decode("utf-8")
         
-        payload = {
-            "agentMode": {},
-            "codeModelMode": True,
-            "id": "XM7KpOE",
-            "isMicMode": False,
-            "maxTokens": None,
-            "messages": [
-                {
-                    "id": "XM7KpOE",
-                    "content": urllib.parse.unquote(args),
-                    "role": "user"
-                }
-            ],
-            "previewToken": None,
-            "trendingAgentMode": {},
-            "userId": "87cdaa48-cdad-4dda-bef5-6087d6fc72f6",
-            "userSystemPrompt": None
-        }
-
-        headers = {
-            'Content-Type': 'application/json',
-            'Cookie': 'sessionId=f77a91e1-cbe1-47d0-b138-c2e23eeb5dcf; intercom-id-jlmqxicb=4cf07dd8-742e-4e3f-81de-38669816d300; intercom-device-id-jlmqxicb=1eafaacb-f18d-402a-8255-b763cf390df6; intercom-session-jlmqxicb=',
-            'Origin': 'https://www.blackbox.ai',
-            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/121.0.0.0 Safari/537.36'
-        }
-        try:
-            response = requests.post(url, json=payload, headers=headers)
-            if response.status_code == 200:
-                return {"results": response.text, "join": "@Mr_Sukkun", "success": True}
-        except Exception as e:
-            return e  
-    def chatgpt(self,args:str,mode:str=False):
-       
-        """
-        Sends a query to a specified chatgpt API endpoint to retrieve a response based on the provided question.
         
-
-        Args:
-            args (str): The question or input for the chatgpt.
-            mode(str) : this  parameter is used to select different models of Chatgpt
-                        available modes are "girlfriend","anime","animev2","flirt","santa","elonmusk"
-
-        Returns:
-            str: The response text from the chatgpt API.
-
-        Example usage:
-        >>> from MukeshAPI import api
-        >>> response = api.chatgpt("hi babe?",mode="girlfriend")
-        >>> print(response)
-        """
-        if not mode:
-            session = requests.Session()
-            response_data=payloads_response(payloads=payload8,args=args)
-            url = "https://api.exh.ai/chatbot/v1/get_response"
-            headers = {
-            "Authorization": "Bearer eyJhbGciOiJIUzUxMiJ9.eyJ1c2VybmFtZSI6ImJvdGlmeS13ZWItdjMifQ.O-w89I5aX2OE_i4k6jdHZJEDWECSUfOb1lr9UdVH4oTPMkFGUNm9BNzoQjcXOu8NEiIXq64-481hnenHdUrXfg",
-            "Content-Type": "application/json",
-            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/122.0.0.0 Safari/537.36"
-        }
-            response = session.post(url, headers=headers, data=json.dumps(response_data))
-            return {"results":response.json()["response"],"join": "@Mr_Sukkun", "success": True}
-        else:
-            try:
-                result = gpt_4_mode(args, mode)
-                return {"results":result,"join": "@Mr_Sukkun", "success": True}
-                
-            except Exception as e:
-                return e      
-    def password(self, num: int = 12)-> str:
+        response = session.get(url+urlquote(args))
+        return {"results": response.json()["data"], "join": "@Mr_Sukkun", "success": True}
+        
+   
+    @staticmethod 
+    def password(num: int = 12)-> str:
         """
         This function generates a random password by combining uppercase letters, lowercase letters, punctuation marks, and digits.
 
@@ -186,34 +135,37 @@ class MukeshAPI:
         - str: A randomly generated password consisting of characters from string.ascii_letters, string.punctuation, and string.digits.
 
         Example usage:
-        >>> from MukeshAPI import api
-        >>> api.password()
-        'r$6Ag~P{32F+'
-        >>> api.password(10)
-        'ZnK"9|?v3a'
+            >>> from MukeshAPI import api
+            >>> api.password()
+            >>> 'r$6Ag~P{32F+'
+            >>> api.password(10)
+            >>> 'ZnK"9|?v3a'
         """
         characters = string.ascii_letters + string.punctuation + string.digits
         password = "".join(random.sample(characters, num))
         return password
     
-    def randomword(self):
+    @staticmethod
+    def randomword():
         """
-        Generate random word . ✨
+        Generate random word.
 
         Returns:
             : A random word from json file.
 
         Example usage:
-        >>> from MukeshAPI import api
-        >>> word = api.randomword()
-        >>> print(word)
+            >>> from MukeshAPI import api
+            >>> word = api.randomword()
+            >>> print(word)
         """
         
         word = random.choice(wordshub)
         return {"results": word, "join": "@Mr_Sukkun", "sucess": True}
-    def gemini(self, args: str) -> dict:
+    
+    @staticmethod
+    def gemini(args: str) -> dict:
         """
-        Generate content using the Gemini API. ✨
+        Generate content using the Gemini API.
 
         Args:
             args (str): The input text to generate content.
@@ -222,11 +174,11 @@ class MukeshAPI:
             dict: A dictionary containing the generated content with metadata.
 
         Example usage:
-        >>> from MukeshAPI import api
-        >>> generated_content = api.gemini("Hello, how are you?")
-        >>> print(generated_content)
+            >>> from MukeshAPI import api
+            >>> generated_content = api.gemini("Hello, how are you?")
+            >>> print(generated_content)
         """
-        url = m('aHR0cHM6Ly9nZW5lcmF0aXZlbGFuZ3VhZ2UuZ29vZ2xlYXBpcy5jb20vdjFiZXRhL21vZGVscy9nZW1pbmktcHJvOmdlbmVyYXRlQ29udGVudD9rZXk9QUl6YVN5QlFhb1VGLUtXalBWXzRBQnRTTjBEUTBSUGtOZUNoNHRN').decode("utf-8")
+        url = m('aHR0cHM6Ly9nZW5lcmF0aXZlbGFuZ3VhZ2UuZ29vZ2xlYXBpcy5jb20vdjFiZXRhL21vZGVscy9nZW1pbmktcHJvOmdlbmVyYXRlQ29udGVudD9rZXk9QUl6YVN5QkM5aXFERF81Z3FjQzJ0NGxrNHhXckdqVzZ0dUpreVFj').decode("utf-8")
         headers = {'Content-Type': 'application/json'}
         payload = {
             'contents': [
@@ -241,8 +193,8 @@ class MukeshAPI:
                 return {"results":generated_text,"join": "@Mr_Sukkun", "success": True}
         except Exception as e:
             return e
-
-    def hashtag(self, arg: str)-> list:
+    @staticmethod
+    def hashtag(arg: str) -> list:
         """
         Generate hashtags based on the given keyword using a specific website.
         
@@ -250,21 +202,36 @@ class MukeshAPI:
         arg (str): The keyword for which hashtags need to be generated.
         
         Returns:
-        str: A string of hashtags related to the given keyword.
+        list: A list of hashtags related to the given keyword.
         
         Example usage:
-        >>> from MukeshAPI import api
-        >>> keyword = "python"
-        >>> hashtags = api.hashtag(keyword)
-        >>> print(hashtags)
+            >>> from MukeshAPI import api
+            >>> keyword = "python"
+            >>> hashtags = api.hashtag(keyword)
+            >>> print(hashtags)
         """
-        url = base64.b64decode("aHR0cHM6Ly9hbGwtaGFzaHRhZy5jb20vbGlicmFyeS9jb250ZW50cy9hamF4X2dlbmVyYXRvci5waHA=").decode("utf-8")
-        data = {"keyword": arg, "filter": "top"}
-        response = requests.post(url, data=data).text
-        content = BeautifulSoup(response, "html.parser").find("div", {"class": "copy-hashtags"}).string
-        output=content.split()
-        return output
-    def chatbot(self,args:str)->str:
+        url = m("aHR0cHM6Ly9hbGwtaGFzaHRhZy5jb20vbGlicmFyeS9hY3Rpb25zL2FqYXgta2V5d29yZC1nZW5lcmF0b3IucGhw").decode("utf-8")
+        data = {"keyword": urlquote(arg), "filter": "top"}
+        headers = {
+            "authority": "all-hashtag.com",
+            "content-type": "application/x-www-form-urlencoded; charset=UTF-8",
+            "cookie": "PHPSESSID=7309f460b65badb6b7532b331203848f; guestAH=%7B%22date%22%3A%222025-01-12%22%2C%22count%22%3A2%7D",
+            "origin": "https://all-hashtag.com",
+            "referer": "https://all-hashtag.com/hashtag-generator.php",
+            "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
+        }
+        response = requests.post(url, data=data, headers=headers).text
+        soup = BeautifulSoup(response, "html.parser")
+        result_div = soup.find("div", class_="hashtags-result")
+        if result_div:
+            content = result_div.text
+            output = content.split()
+            return output
+        else:
+            return {"error": "No hashtags found"}
+    
+    @staticmethod
+    def chatbot(args: str) -> str:
         """
         Interact with a chatbot to get a response based on the provided input text.
 
@@ -275,17 +242,30 @@ class MukeshAPI:
         str: The response from the chatbot based on the input text.
 
         Example usage:
-        >>> from MukeshAPI import api
-        >>> user_input = "Hello, how are you?"
-        >>> response = api.chatbot(user_input)
-        >>> print(response)
-        """
-        x = base64.b64decode("aHR0cHM6Ly9mYWxsZW54Ym90LnZlcmNlbC5hcHAvYXBpL2FwaWtleT01OTM1NjA4Mjk3LWZhbGxlbi11c2JrMzNrYnN1L2dyb3VwLWNvbnRyb2xsZXIvbXVrZXNoL21lc3NhZ2U9").decode("utf-8")
-        full_url = f"{x}{args}"
-        response = requests.get(full_url).json()["reply"]
-        return response
+            >>> from MukeshAPI import API
+            >>> user_input = "Hello, how are you?"
+            >>> response = API.chatbot(user_input)
+            >>> print(response)
 
-    def bhagwatgita(self,chapter: int, shalok: int = 1) -> requests.Response:
+        Note:
+            Make sure that your network is active, and the endpoint is reachable for a successful request.
+        """
+        try:
+            # Decode the base64 encoded URL
+            base_url = base64.b64decode("aHR0cHM6Ly9jaGF0d2l0aGFpLmNvZGVzZWFyY2gud29ya2Vycy5kZXYvP2NoYXQ9").decode("utf-8")
+            full_url = f"{base_url}{urlquote(args)}"  # Ensure args is included in the query parameters
+
+            response = requests.get(full_url)
+            response.raise_for_status() 
+            return response.json().get("data", "No reply found.")
+        
+        except requests.RequestException as e:
+            return f"Error: {str(e)}"
+        except Exception as e:
+            return f"An unexpected error occurred: {str(e)}"
+
+    @staticmethod
+    def bhagwatgita(chapter: int, shalok: int = 1) -> requests.Response:
         """
         Retrieve a verse from the Bhagavad Gita based on the provided chapter and shalok number.
 
@@ -297,9 +277,9 @@ class MukeshAPI:
         dict: A dictionary containing the chapter number, verse text, chapter introduction, and the specified shalok text.
 
         Example usage:
-        >>> from MukeshAPI import api
-        >>> verse_data = api.bhagwatgita(1, 5)
-        >>> print(verse_data)
+            >>> from MukeshAPI import api
+            >>> verse_data = api.bhagwatgita(1, 5)
+            >>> print(verse_data)
         """
         xc=base64.b64decode("aHR0cHM6Ly93d3cuaG9seS1iaGFnYXZhZC1naXRhLm9yZy9jaGFwdGVyLw==").decode(encoding="utf-8")
         url = f"{xc}{chapter}/hi"
@@ -318,38 +298,43 @@ class MukeshAPI:
 
         return data
 
-
-    def imdb(self,args: str) -> dict:
+    
+    @staticmethod
+    def imdb(args: str) -> dict:
         """
         Retrieve information about a movie or TV show from IMDb based on the search query.
 
         Args:
-        args (str): The movie or TV show to search for on IMDb.
+            args (str): The movie or TV show to search for on IMDb.
 
         Returns:
-        dict: A dictionary containing details about the movie or TV show, such as name, description, genre,
-            actors, trailer link, and more.
+            dict: A dictionary containing details about the movie or TV show, such as name, description, genre,
+                actors, trailer link, and more.
 
         Example usage:
-        >>> from MukeshAPI import api
-        >>> movie_data = api.imdb("The Godfather")
-        >>> print(movie_data)
+            >>> from MukeshAPI import api
+            >>> movie_data = api.imdb("The Godfather")
+            >>> print(movie_data)
         """
-
+        
         session = HTMLSession()
 
         url = f"https://www.imdb.com/find?q={args}"
         response = session.get(url)
         results = response.html.xpath("//section[@data-testid='find-results-section-title']/div/ul/li")
-        urls = [result.find("a")[0].attrs["href"] for result in results][0]
+        
+        if not results:
+            return {"success": False, "message": "No results found."}
 
+        urls = [result.find("a")[0].attrs["href"] for result in results][0]
         headers = {
-            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.3"
+            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) "
+                        "AppleWebKit/537.36 (KHTML, like Gecko) "
+                        "Chrome/58.0.3029.110 Safari/537.3"
         }
         response = requests.get(f"https://www.imdb.com/{urls}", headers=headers)
 
         soup = BeautifulSoup(response.text, "html.parser")
-
         movie_name = soup.title.text.strip()
 
         meta_tags = soup.find_all("meta")
@@ -365,58 +350,39 @@ class MukeshAPI:
         json_data = soup.find("script", type="application/ld+json").string
         parsed_json = json.loads(json_data)
 
-        movie_url = parsed_json["url"]
-        movie_image = parsed_json["image"]
-        movie_description = parsed_json["description"]
-        movie_review_body = parsed_json["review"]["reviewBody"]
-        movie_review_rating = parsed_json["review"]["reviewRating"]["ratingValue"]
-        movie_genre = parsed_json["genre"]
-        movie_actors = [actor["name"] for actor in parsed_json["actor"]]
-        movie_trailer = parsed_json["trailer"]
-        
-        output = []
-        for result in results:
-            name = result.text.replace("\n", " ")
-            url = result.find("a")[0].attrs["href"]
-            if ("Podcast" not in name) and ("Music Video" not in name):
-                try:
-                    image = result.xpath("//img")[0].attrs["src"]
-                    file_id = url.split("/")[2]
-                    output.append({
-                        "movie_name": movie_name,
-                        "id": file_id,
-                        "poster": image,
-                        "description": description,
-                        "keywords": keywords,
-                        "movie_url": movie_url,
-                        "movie_image": movie_image,
-                        "movie_description": movie_description,
-                        "movie_review_body": movie_review_body,
-                        "movie_review_rating": movie_review_rating,
-                        "movie_genre": movie_genre,
-                        "movie_actors": movie_actors,
-                        "movie_trailer": movie_trailer,
-                        "join": "@Mr_Sukkun",
-                        "success": True,
-                    })
-                    return {"results": output}
-                except:
-                    return {"Success": False}
-    def morse_encode(self,args:str)->str:
+        output = {
+            "movie_name": movie_name,
+            "movie_url": parsed_json["url"],
+            "movie_image": parsed_json["image"],
+            "movie_description": parsed_json["description"],
+            'description': description,
+            'keywords': keywords,
+            "movie_review_body": parsed_json["review"]["reviewBody"],
+            "movie_review_rating": parsed_json["review"]["reviewRating"]["ratingValue"],
+            "movie_genre": parsed_json["genre"],
+            "movie_actors": [actor["name"] for actor in parsed_json["actor"]],
+            "movie_trailer": parsed_json["trailer"],
+            "success": True,
+        }
+
+        return {"results": [output]}
+
+    @staticmethod
+    def morse_encode(args:str)->str:
         """
-    Encode the input string into Morse code.
+        Encode the input string into Morse code.
 
-    Args:
-        args (str): The input string to be encoded into Morse code. ✨
+        Args:
+            args (str): The input string to be encoded into Morse code.
 
-    Returns:
-        str: The Morse code representation of the input string along with additional information. 🔠
+        Returns:
+            str: The Morse code representation of the input string along with additional information.
 
-    Example usage:
-    >>> from MukeshAPI import api
-    >>> encoded_result = api.morse_encode("Hello World")
-    >>> print(encoded_result)
-    """
+        Example usage:
+            >>> from MukeshAPI import api
+            >>> encoded_result = api.morse_encode("Hello World")
+            >>> print(encoded_result)
+        """
 
         cipher = ""
         for letter in args.upper():
@@ -432,7 +398,9 @@ class MukeshAPI:
         }
         return (output)
     
-    def morse_decode(self,args: str) -> str:
+    
+    @staticmethod
+    def morse_decode(args: str) -> str:
         """
     Decode the Morse code back into the original text. 🔄
 
@@ -443,9 +411,9 @@ class MukeshAPI:
         str: The decoded text from the Morse code.
 
     Example usage:
-    >>> from MukeshAPI import api
-    >>> decoded_result =api.morse_decode(".... . .-.. .-.. --- / .-- --- .-. .-.. -..")
-    >>> print(decoded_result)
+        >>> from MukeshAPI import api
+        >>> decoded_result =api.morse_decode(".... . .-.. .-.. --- / .-- --- .-. .-.. -..")
+        >>> print(decoded_result)
     """
 
         args += " "
@@ -471,23 +439,22 @@ class MukeshAPI:
         return output
        
     
-    def unsplash(self,args)->requests.Response:
+    @staticmethod
+    def unsplash(args) -> requests.Response:
         """
-    Get image URLs related to the query using the iStockphoto API.
+        Get image URLs related to the query using the iStockphoto API.
 
-    Args:
-        args (str): The search query for images.
+        Args:
+            args (str): The search query for images.
 
-    Returns:
-        list: List of image URLs related to the query.
-        
-    Example usage:
-    >>> from MukeshAPI import api
-    >>> response = api.unsplash("boy image")
-    >>> print(response)
-    
+        Returns:
+            dict: A dictionary containing a list of image URLs related to the query and additional metadata.
 
-    """
+        Example usage:
+            >>> from MukeshAPI import api
+            >>> response = api.unsplash("boy image")
+            >>> print(response)
+        """
         url = f'https://www.istockphoto.com/search/2/image?alloweduse=availableforalluses&phrase={args}&sort=best'
         headers = {
             'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/121.0.0.0 Safari/537.36',
@@ -495,17 +462,15 @@ class MukeshAPI:
             'Referer': 'https://unsplash.com/'}
         response = requests.get(url, headers=headers)
         if response.status_code == 200:
-            
-        
             soup = BeautifulSoup(response.content, 'html.parser')
             image_tags = soup.find_all('img')
             image_urls = [img['src'] for img in image_tags if img['src'].startswith('https://media.istockphoto.com')]
-            
             return {"results": image_urls, "join": "@Mr_Sukkun", "success": True}
         else:
             return {f"status code: {response.status_code}"}
-        
-    def leetcode(self,username):
+      
+    @staticmethod  
+    def leetcode(username):
         """
     Retrieve user data including activity streak, profile information, and contest badges from LeetCode using GraphQL API.
 
@@ -516,9 +481,9 @@ class MukeshAPI:
         dict: A dictionary containing user data such as streak, total active days, badges, user profile information, and social media URLs.
 
     Example usage:
-    >>> from MukeshAPI import api
-    >>> user_data = api.leetcode("noob-mukesh")
-    >>> print(user_data)"""
+        >>> from MukeshAPI import api
+        >>> user_data = api.leetcode("noob-mukesh")
+        >>> print(user_data)"""
         url = base64.b64decode('aHR0cHM6Ly9sZWV0Y29kZS5jb20vZ3JhcGhxbC8=').decode("utf-8")
 
         payload = {
@@ -610,7 +575,8 @@ class MukeshAPI:
             return e
         
     
-    def pypi(self,args):
+    @staticmethod
+    def pypi(args):
         """
     Retrieve package information from the Python Package Index (PyPI) by providing the package name.
 
@@ -621,9 +587,9 @@ class MukeshAPI:
         dict: A dictionary containing information about the specified package, such as name, version, description, author, license, and more.
 
     Example usage:
-    >>> from MukeshAPI import api
-    >>> package_info = api.pypi("requests")
-    >>> print(package_info)
+        >>> from MukeshAPI import api
+        >>> package_info = api.pypi("requests")
+        >>> print(package_info)
     """
    
         n = base64.b64decode("aHR0cHM6Ly9weXBpLm9yZy9weXBpLw==").decode("utf-8")
@@ -631,7 +597,8 @@ class MukeshAPI:
         return result
     
     
-    def repo(self,args):
+    @staticmethod
+    def repo(args):
         """
     Search GitHub repositories based on the search query provided.
 
@@ -642,9 +609,9 @@ class MukeshAPI:
         dict: A dictionary containing search results of GitHub repositories. Each entry includes an index and corresponding repository.
 
     Example usage:
-    >>> from MukeshAPI import api
-    >>> search_results = api.repo("MukeshRobot")
-    >>> print(search_results)
+        >>> from MukeshAPI import api
+        >>> search_results = api.repo("MukeshRobot")
+        >>> print(search_results)
     """
         
         n = base64.b64decode("aHR0cHM6Ly9hcGkuZ2l0aHViLmNvbS9zZWFyY2gvcmVwb3NpdG9yaWVzP3E9"
@@ -656,7 +623,9 @@ class MukeshAPI:
             result.append((index, item))
 
         return {"results": result, "join": "@Mr_Sukkun", "sucess": True}
-    def github(self,args):
+    
+    @staticmethod
+    def github(args):
         """
     Search GitHub information based on the username query provided.
 
@@ -667,9 +636,9 @@ class MukeshAPI:
         dict: A dictionary containing search results of GitHub username .
 
     Example usage:
-    >>> from MukeshAPI import api
-    >>> search_results = api.github("noob-mukesh")
-    >>> print(search_results)
+        >>> from MukeshAPI import api
+        >>> search_results = api.github("noob-mukesh")
+        >>> print(search_results)
     """
 
         n = base64.b64decode("aHR0cHM6Ly9hcGkuZ2l0aHViLmNvbS91c2Vycy8=").decode("utf-8")
@@ -706,7 +675,9 @@ class MukeshAPI:
             "following": following,
         }
         return results
-    def meme(self):
+    
+    @staticmethod
+    def meme():
         """ Fetch  random memes from reddit
         
         Returns:
@@ -714,9 +685,9 @@ class MukeshAPI:
         dict: A dictionary containing search results of meme
         
         Example usage:
-        >>> from MukeshAPI import api
-        >>> search_results = api.meme()
-        >>> print(search_results)
+            >>> from MukeshAPI import api
+            >>> search_results = api.meme()
+            >>> print(search_results)
         """
 
         n = base64.b64decode("aHR0cHM6Ly9tZW1lLWFwaS5jb20vZ2ltbWU=").decode("utf-8")
@@ -726,5 +697,144 @@ class MukeshAPI:
         results = {"title": title, "url": url}
         return results
     
+    @staticmethod
+    def weather(city: str) -> dict:
+        """Retrieves weather data for a specified city using a remote weather API.
 
+    Args:
+        city (str): The name of the city for which weather data is requested.
+
+    Returns:
+        dict: A JSON response containing weather data for the specified city.
+        
+    Example usage:
+        >>> from MukeshAPI import api
+        >>> weather_data = api.weather("Bihar")
+        >>> print(weather_data)
+    """
+    
+        url = m("aHR0cHM6Ly93ZWF0aGVyeGFwaS5kZW5vLmRldi93ZWF0aGVyP2NpdHk9").decode("utf-8")
+        results = requests.get(f"{url}{city}")
+        return results.json()
+
+    @staticmethod
+    def upload_image(image_url=None, image_file=None) -> str:
+        """
+        Uploads an image to ImgBB and returns the URL of the uploaded image.
+
+        Args:
+            image_url (str, optional): The URL of the image to upload.
+            image_file (file, optional): The file object of the image to upload.
+
+        Returns:
+            str: The URL of the uploaded image.
+        
+        """
+
+        if image_url is None and image_file is None:
+            raise ValueError("Either image_url or image_file must be provided.")
+
+        if image_url is not None:
+            image = image_url
+        else:
+            image = base64.b64encode(image_file.read())
+
+        payload = {'key': "b90a7d977b2aa510ef101de4f4b1876d", 'image': image}
+
+        response = requests.post("https://api.imgbb.com/1/upload", data=payload)
+
+        if response.status_code == 200:
+            return response.json()
+        else:
+            response.raise_for_status()
+    @staticmethod
+    def truth():
+        truth_string=random.choice(TRUTH)
+        return truth_string
+    
+    @staticmethod
+    def dare():
+        dare_string=random.choice(DARE)
+        return dare_string
+    
+    @staticmethod
+    def ai_image(prompt: str) -> bytes:
+        """Generates an AI-generated image based on the provided prompt.
+
+        Args:
+            prompt (str): The input prompt for generating the image.
+
+        Returns:
+            bytes: The generated image in bytes format.
+            
+        Example usage:
+            >>> from MukeshAPI import api
+            >>> generated_image= api.ai_image("boy image")
+            >>> print(generated_image)
+        """
+        url = base64.b64decode('aHR0cHM6Ly9haS1hcGkubWFnaWNzdHVkaW8uY29tL2FwaS9haS1hcnQtZ2VuZXJhdG9y').decode("utf-8")
+
+        form_data = {
+            'prompt': prompt,
+            'output_format': 'bytes',
+            'request_timestamp': str(int(time.time())),
+            'user_is_subscribed': 'false',
+        }
+
+        response = requests.post(url, data=form_data)
+        if response.status_code == 200:
+            try:
+                if response.content:
+                    return response.content
+                else:
+                    raise Exception("Failed to get image from the server.")
+            except Exception as e:
+                raise e
+        else:
+            raise Exception("Error:", response.status_code)
+
+    @staticmethod
+    def stickers(query: str, pages: int = 5) -> list:
+        """
+        Fetches sticker packs based on the provided query.
+
+        Args:
+            query (str): The search term for finding sticker packs.
+            pages (int, optional): The number of pages to search. Defaults to 5.
+
+        Returns:
+            list: A list containing the search results.
+        
+        Example usage:
+            >>> from MukeshAPI import api
+            >>> stickers_result = api.stickers("funny cats")
+            >>> print(stickers_result)
+        """
+        scraper = CloudScraper()
+        combot_stickers_url = base64.b64decode("aHR0cHM6Ly9jb21ib3Qub3JnL3N0aWNrZXJzP3E9").decode("utf-8")
+        result = []
+        for page in range(1, pages + 1):
+            text = scraper.get(f"{combot_stickers_url}&page={page}&{urlquote(query.replace(" ",""))}").text
+            soup = BeautifulSoup(text, "lxml")
+            div = soup.find("main", class_="site__content")
+            titles = div.find_all("a", "stickerset__title")
+            
+            if titles:
+                for pack in titles:
+                    link = "https://t.me/addstickers/" + pack["href"].replace("/stickers/", "")
+                    title_text = pack.get_text(strip=True)
+                    result.append({"title": title_text, "link": link})
+            elif page == 1:
+                result.append({"message": "No results found, try a different term"})
+                break
+            else:
+                result.append({"message": "Interestingly, there's nothing here."})
+                break
+        
+        return result
+
+           
 api=MukeshAPI()
+
+
+
